@@ -1,6 +1,7 @@
 controlBMAgamma0 <-
 function(maxIter = Inf, tol = sqrt(.Machine$double.eps), power = (1/3),
-         rainobs = 10, init = list(varCoefs = NULL, weights = NULL)) 
+         rainobs = 10, init = list(varCoefs = NULL, weights = NULL),
+         optim.control = list(ndeps = rep(sqrt(.Machine$double.eps),2))) 
 {
 #
 # copyright 2006-present, University of Washington. All rights reserved.
@@ -9,6 +10,6 @@ function(maxIter = Inf, tol = sqrt(.Machine$double.eps), power = (1/3),
 
  if (is.infinite(maxIter) && maxIter > 0) maxIter <- .Machine$integer.max
  list(maxIter = maxIter, tol = tol, power = power, rainobs = rainobs,
-      init = init) 
+      init = init, optim.control = optim.control) 
 }
 
